Changelog
=========

Changes as of 25 September 2018

0.1.0 <25 September 2018>
^^^^^^^^^^^^^^^^^^^^^^^^^

- Initial beta release to PyPy
- Implementation of most planned functionality
- 100% test coverage
- Clean bill of health from the various linters and MyPy
- Loading of file specified by an environment variable (@cthoyt)
